A Python tool that calculates Bayesian credibility intervals for online polling using [the Ipsos method](https://www.ipsos.com/sites/default/files/2017-03/IpsosPA_CredibilityIntervals.pdf)

## Other resources

- [Ipsos white paper](https://www.ipsos.com/sites/default/files/2017-03/IpsosPA_CredibilityIntervals.pdf)
- [Documentation](https://palewi.re/docs/ipsos-credibility-interval/)
- [PyPI package](https://pypi.org/project/ipsos-credibility-interval/)
